FeatureFileSpec

Struct FeatureFileSpec 

pub struct FeatureFileSpec {
    pub path: &'static str,
    pub unit_name: &'static str,
    pub todo_line: &'static str,
}
A single feature C file that a project template generates.

Fields

path: &'static str

Path relative to project root, e.g. “src/features/sensor_pipeline.c”.

unit_name: &'static str

C identifier stem used in the generated function name, e.g. “sensor_pipeline”.

todo_line: &'static str

TODO comment inserted into the function body.