ModuleScaffoldInput

Struct ModuleScaffoldInput 

pub struct ModuleScaffoldInput {
    pub template_id: ModuleTemplateId,
    pub module_name: String,
    pub destination: String,
}
Inputs needed to plan a module scaffold from a module template.

Fields

template_id: ModuleTemplateId

Module template to scaffold from.

module_name: String

Raw module name as provided by the caller (normalized during planning).

destination: String

Target directory the plan is rooted at.