pub struct FeatureFileSpec {
pub path: &'static str,
pub unit_name: &'static str,
pub todo_line: &'static str,
}Expand description
A single feature C file that a project template generates.
Fields
path: &'static strPath relative to project root, e.g. “src/features/sensor_pipeline.c”.
unit_name: &'static strC identifier stem used in the generated function name, e.g. “sensor_pipeline”.
todo_line: &'static strTODO comment inserted into the function body.