pub struct ModuleScaffoldInput {
pub template_id: ModuleTemplateId,
pub module_name: String,
pub destination: String,
}Expand description
Inputs needed to plan a module scaffold from a module template.
Fields
template_id: ModuleTemplateIdModule template to scaffold from.
module_name: StringRaw module name as provided by the caller (normalized during planning).
destination: StringTarget directory the plan is rooted at.